        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 24 <strong>control</strong><br>0,1,2,6,8,9,11,12,14,15,17,18,19,20,22,24,27,28,30,32,36,46,48,50';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 17 <br>3,13,16,21,25,29,33,35,37,38,39,40,42,43,44,45,47';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 10 <br>4,5,7,10,23,26,31,34,41,49';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 24 <strong>control</strong><br>0,1,2,6,8,9,11,12,14,15,17,18,19,20,22,24,27,28,30,32,36,46,48,50';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 17 <br>3,13,16,21,25,29,33,35,37,38,39,40,42,43,44,45,47';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 10 <br>4,5,7,10,23,26,31,34,41,49';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 24 <strong>control</strong><br>0,1,2,6,8,9,11,12,14,15,17,18,19,20,22,24,27,28,30,32,36,46,48,50';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 17 <br>3,13,16,21,25,29,33,35,37,38,39,40,42,43,44,45,47';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 10 <br>4,5,7,10,23,26,31,34,41,49';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 24 <strong>control</strong><br>0,1,2,6,8,9,11,12,14,15,17,18,19,20,22,24,27,28,30,32,36,46,48,50';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 17 <br>3,13,16,21,25,29,33,35,37,38,39,40,42,43,44,45,47';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 10 <br>4,5,7,10,23,26,31,34,41,49';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 24 <strong>control</strong><br>0,1,2,6,8,9,11,12,14,15,17,18,19,20,22,24,27,28,30,32,36,46,48,50';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 17 <br>3,13,16,21,25,29,33,35,37,38,39,40,42,43,44,45,47';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 10 <br>4,5,7,10,23,26,31,34,41,49';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 24 <strong>control</strong><br>0,1,2,6,8,9,11,12,14,15,17,18,19,20,22,24,27,28,30,32,36,46,48,50';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>43</strong> miembros: 17 <br>3,13,16,21,25,29,33,35,37,38,39,40,42,43,44,45,47';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260514 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>49</strong> miembros: 10 <br>4,5,7,10,23,26,31,34,41,49';}
}
